@@ -20,8 +20,12 @@ def get_file_handler():
 
 def get_logger(logger_name, add_log_file=False):
     logger = logging.getLogger(logger_name)
-    logger.setLevel(logging.INFO)
-    logger.addHandler(get_console_handler())
+    # logger.setLevel(logging.INFO)
+    logger.setLevel(logging.DEBUG)
+    # logger.addHandler(get_console_handler())
+    # requests_log = logging.getLogger("requests.packages.urllib3")
+    # requests_log.setLevel(logging.DEBUG)
+    # requests_log.propagate = True
     if add_log_file:
         logger.addHandler(get_file_handler())
     logger.propagate = False
